times is an n x 2 matrix with times[,1] being the left side of the interval and times[,2] is the right side), or bivariate interval censored data (where times is an n x 4 matrix with times[,1:2] being left and right side of the interval for event 1 and times[,3:4] being the left and right side of the interval for event 2).ICNPMLE(times, B = c(1,1), max.inner = 100, max.outer = 100, tol = 1e-10)data.frame or matrix of censoring intervalsYu, Y., (2010), Improved EM for Mixture Proportions with Applications to Nonparametric ML Estimation for Censored Data, preprint
Maathuis, M., (2005). Reduction algorithm for the NPMLE for the distribution function of bivariate interval censored data. Journal of Computational and Graphical Statistics Vol 14 pp 252- 262
simData <- simBVCen(500)
fit <- ICNPMLE(simData)
fitRun the code above in your browser using DataLab